/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Client.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.ant.archive;

import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;
import org.ow2.easybeans.ant.archive.api.IClient;
import org.ow2.easybeans.ant.archive.file.ClientFile;
import org.ow2.easybeans.ant.archive.info.ClientInfo;

/**
 * Task that creates a client archive (only .jar file).
 * @author Florent Benoit
 */
public class Client extends AbsArchive {

    /**
     * Name of the Main-Class attribute.
     */
    private String mainClassAttribute = null;

    /**
     * Default constructor.
     */
    public Client() {
        super();
    }

    /**
     * Execute the task.
     */
    @Override
    public void execute() {

        log("Building Client in '" + getDest() + "'.", Project.MSG_INFO);

        IClient client = null;

        client = new ClientFile(getProject());

        // Set the name of the task
        ((Task) client).setTaskName(getTaskName());

        // Build the info object
        ClientInfo clientInfo = new ClientInfo();
        client.setClientInfo(clientInfo);

        // Fill archive properties
        updateArchiveInfo(clientInfo);

        // complete
        clientInfo.setMainClass(mainClassAttribute);

        // no exploded mode yet
        clientInfo.setExploded(false);

        // Execute the task
        client.execute();
    }

    /**
     * Sets the Main-Class: Attribute of the manifest.
     * @param mainClassAttribute the value of the Main-Class attribute
     */
    public void setMainClass(final String mainClassAttribute) {
        this.mainClassAttribute = mainClassAttribute;
    }

}
