/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.container.session;

import javax.ejb.EJBLocalObject;
import javax.ejb.EJBObject;
import javax.ejb.SessionContext;
import javax.transaction.Transaction;

import org.ow2.easybeans.api.bean.EasyBeansSB;
import org.ow2.easybeans.api.container.EZBSessionContext;
import org.ow2.easybeans.container.EasyBeansEJBContext;

/**
 * Defines the Session Context used by Stateless and Stateful beans.
 * @param <BeanType> Could be a stateless or stateful.
 * @author Florent Benoit
 */
public class EasyBeansSessionContext<BeanType extends EasyBeansSB<?>> extends EasyBeansEJBContext<BeanType> implements
        EZBSessionContext<BeanType>, SessionContext {

    /**
     * Reference to the bean.
     */
    private BeanType bean = null;

    /**
     * Transaction used by this bean. (Used by stateful bean).
     */
    private Transaction beanTransaction = null;

    /**
     * Gets the transaction used by this bean.
     * @return the bean transaction.
     */
    public Transaction getBeanTransaction() {
        return beanTransaction;
    }

    /**
     * Sets the transaction used by this bean.
     * @param beanTransaction the bean transaction.
     */
    public void setBeanTransaction(final Transaction beanTransaction) {
        this.beanTransaction = beanTransaction;
    }

    /**
     * Gets the bean of this context.
     * @return bean used by this context.
     */
    @Override
    public BeanType getBean() {
        return this.bean;
    }

    /**
     * Build a new Session context.
     * @param bean the bean on which we are linked.
     */
    public EasyBeansSessionContext(final BeanType bean) {
        super(bean.getEasyBeansFactory());
        this.bean = bean;
    }

    /**
     * Obtain a reference to the EJB local object that is associated with the
     * instance. An instance of a session enterprise Bean can call this method
     * at anytime between the ejbCreate() and ejbRemove() methods, including
     * from within the ejbCreate() and ejbRemove() methods. An instance can use
     * this method, for example, when it wants to pass a reference to itself in
     * a method argument or result.
     * @return The EJB local object currently associated with the instance.
     * @throws java.lang.IllegalStateException - Thrown if the instance invokes
     *         this method while the instance is in a state that does not allow
     *         the instance to invoke this method, or if the instance does not
     *         have a local interface.
     */
    public EJBLocalObject getEJBLocalObject() throws java.lang.IllegalStateException {
        throw new UnsupportedOperationException();
    }

    /**
     * Obtain a reference to the EJB object that is currently associated with
     * the instance. An instance of a session enterprise Bean can call this
     * method at anytime between the ejbCreate() and ejbRemove() methods,
     * including from within the ejbCreate() and ejbRemove() methods. An
     * instance can use this method, for example, when it wants to pass a
     * reference to itself in a method argument or result.
     * @return The EJB object currently associated with the instance.
     * @throws java.lang.IllegalStateException - Thrown if the instance invokes
     *         this method while the instance is in a state that does not allow
     *         the instance to invoke this method, or if the instance does not
     *         have a remote interface.
     */
    public EJBObject getEJBObject() throws java.lang.IllegalStateException {
        throw new UnsupportedOperationException();
    }

    /**
     * Obtain a reference to the JAX-RPC MessageContext. An instance of a
     * stateless session bean can call this method from any business method
     * invoked through its web service endpoint interface.
     * @return The MessageContext for this web service invocation.
     * @throws java.lang.IllegalStateException - Thrown if this method is
     *         invoked while the instance is in a state that does not allow
     *         access to this method.
     */
    public javax.xml.rpc.handler.MessageContext getMessageContext() throws java.lang.IllegalStateException {
        throw new UnsupportedOperationException("Not implemented");
    }

    /**
     * Obtain an object that can be used to invoke the current bean through the
     * given business interface.
     * @param <T> the interface of the bean
     * @param businessInterface One of the local business interfaces or remote
     *        business interfaces for this session bean.
     * @return The business object corresponding to the given business
     *         interface.
     * @throws IllegalStateException - Thrown if this method is invoked with an
     *         invalid business interface for the current bean.
     */
    public <T> T getBusinessObject(final Class<T> businessInterface) throws IllegalStateException {
        throw new UnsupportedOperationException("Not implemented");
    }

    /**
     * Obtain the business interface through which the current business method
     * invocation was made.
     * @return the business interface through which the current business method
     *         invocation was made.
     * @throws IllegalStateException - Thrown if this method is called and the
     *         bean has not been invoked through a business interface.
     */
    public Class<?> getInvokedBusinessInterface() throws IllegalStateException {
        throw new UnsupportedOperationException("Not implemented");
    }

}
