package org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata;

import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxAnnotationResourcesVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbEJBsVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxPersistencePersistenceContextsVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxPersistencePersistenceUnitsVisitor;
import org.ow2.easybeans.deployment.metadata.CommonClassMetadata;
import org.ow2.easybeans.deployment.metadata.CommonFieldMetadata;
import org.ow2.easybeans.deployment.metadata.CommonMethodMetadata;
import org.ow2.util.scan.api.configurator.metadata.ClassMetadataConfigurator;

/**
 * CommonClassMetadataConfigurator.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class CommonClassMetadataConfigurator<
    C extends CommonClassMetadata<C, M, F>,
    M extends CommonMethodMetadata<C, M, F>,
    F extends CommonFieldMetadata<C, M, F>>
        extends ClassMetadataConfigurator<C, M, F> {

    /**
     * Constructor.
     * @param classMetadata classMetadata
     */
    public CommonClassMetadataConfigurator(final C classMetadata) {
        super(classMetadata);
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitor() {

        C classMetadata = getClassMetadata();

        // add visitor shared with class and field and method
        CommonMetadataConfigurator.initVisitor(getAnnotationVisitors(), classMetadata);

        // add @EJBs
        getAnnotationVisitors().put(JavaxEjbEJBsVisitor.TYPE,
                new JavaxEjbEJBsVisitor(classMetadata));

        // add @Resources
        getAnnotationVisitors().put(JavaxAnnotationResourcesVisitor.TYPE,
                new JavaxAnnotationResourcesVisitor(classMetadata));

        // add @PersistenceContexts
        getAnnotationVisitors().put(JavaxPersistencePersistenceContextsVisitor.TYPE,
                new JavaxPersistencePersistenceContextsVisitor(classMetadata));

        // add @PersistenceUnits
        getAnnotationVisitors().put(JavaxPersistencePersistenceUnitsVisitor.TYPE,
                new JavaxPersistencePersistenceUnitsVisitor(classMetadata));

    }

}
