package org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata.war;

import org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata.CommonClassMetadataConfigurator;
import org.ow2.easybeans.deployment.metadata.war.WarArchiveMetadata;
import org.ow2.easybeans.deployment.metadata.war.WarClassMetadata;
import org.ow2.easybeans.deployment.metadata.war.WarFieldMetadata;
import org.ow2.easybeans.deployment.metadata.war.WarMethodMetadata;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.configurator.IMethodConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;


/**
 * WarClassMetadataConfigurator.
 * @author Gael Lalire
 */
public class WarClassMetadataConfigurator extends
        CommonClassMetadataConfigurator<WarClassMetadata, WarMethodMetadata, WarFieldMetadata> {

    /**
     * WarClassMetadataConfigurator.
     * @param jClass signature
     * @param warArchiveMetadata parent
     */
    public WarClassMetadataConfigurator(final JClass jClass, final WarArchiveMetadata warArchiveMetadata) {
        super(new WarClassMetadata(jClass, warArchiveMetadata));
        registerAnnotationVisitor();
    }

    /**
     * @param jField signature
     * @return configurator
     */
    @Override
    protected IFieldConfigurator createFieldMetadataConfigurator(final JField jField) {
        return new WarFieldMetadataConfigurator(jField, getClassMetadata());
    }

    /**
     * @param jMethod signature
     * @return configurator
     */
    @Override
    protected IMethodConfigurator createMethodMetadataConfigurator(final JMethod jMethod) {
        return new WarMethodMetadataConfigurator(jMethod, getClassMetadata());
    }

    /**
     * add class to archive.
     */
    @Override
    public void configurationComplete() {
       WarClassMetadata warClassMetadata = getClassMetadata();
       warClassMetadata.getWarArchiveMetadata().addWarClassMetadata(warClassMetadata);
    }

}
