/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsAnnotationVisitor.java 2833 2008-04-11 08:09:39Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer.visitors;

import org.ow2.easybeans.deployment.annotations.analyzer.AnnotationType;
import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * This class manages the setter/getter of annotation visitor.
 * @param <T> a metadata object.
 * @author Florent Benoit
 */
public abstract class AbsAnnotationVisitor<T> implements IAnnotationVisitor, AnnotationType {

    /**
     * Linked to an AnnotationMetadata ?
     */
    private T annotationMetadata;

    /**
     * Constructor (default).
     */
    public AbsAnnotationVisitor() {

    }

    /**
     * Constructor.
     * @param annotationMetadata linked to an annotation metadata
     */
    public AbsAnnotationVisitor(final T annotationMetadata) {
        this();
        this.annotationMetadata = annotationMetadata;
    }

    /**
     * Visits a primitive value of the annotation.
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.easybeans.asm.Type}.
     */
    public void visit(final String name, final Object value) {

    }

    /**
     * Visits an enumeration value of the annotation.
     * @param name the value name.
     * @param desc the class descriptor of the enumeration class.
     * @param value the actual enumeration value.
     */
    public void visitEnum(final String name, final String desc, final String value) {

    }

    /**
     * Visits a nested annotation value of the annotation.
     * @param name the value name.
     * @param desc the class descriptor of the nested annotation class.
     * @return a non null visitor to visit the actual nested annotation value.
     *         <i>The nested annotation value must be fully visited before
     *         calling other methods on this annotation visitor</i>.
     */
    public IAnnotationVisitor visitAnnotation(final String name, final String desc) {
        return this;
    }

    /**
     * Visits an array value of the annotation.
     * @param name the value name.
     * @return a non null visitor to visit the actual array value elements. The
     *         'name' parameters passed to the methods of this visitor are
     *         ignored. <i>All the array values must be visited before calling
     *         other methods on this annotation visitor</i>.
     */
    public IAnnotationVisitor visitArray(final String name) {
        return this;
    }

    /**
     * Visits the end of the annotation.
     */
    public abstract void visitEnd();


    /**
     * @return class/method metadata
     */
    public T getAnnotationMetadata() {
        return this.annotationMetadata;
    }



}
