/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EnumAnnotationVisitor.java 2833 2008-04-11 08:09:39Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer.visitors;

import org.ow2.easybeans.deployment.annotations.analyzer.AnnotationType;
import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * This class manages the handling of enum values.
 * @param <T> the ClassAnnotationMetadata or MethodAnnotationMetadata.
 * @author Florent Benoit
 */
public abstract class EnumAnnotationVisitor<T> extends AbsAnnotationVisitor<T> implements IAnnotationVisitor, AnnotationType {

    /**
     * Value.
     */
    private String value = null;


    /**
     * Constructor.
     * @param annotationMetadata linked to a &lt;T&gt; metadata.
     */
    public EnumAnnotationVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits an enumeration value of the annotation.
     * @param name the value name.
     * @param desc the class descriptor of the enumeration class.
     * @param value the actual enumeration value.
     */
    @Override
    public void visitEnum(final String name, final String desc, final String value) {
        this.value = value;
    }

    /**
     * @return value of the object
     */
    public String getValue() {
        return this.value;
    }


}
