/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JActivationConfigProperty.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.impl;

import java.lang.annotation.Annotation;

import javax.ejb.ActivationConfigProperty;

/**
 * Acts as an implementation of &#64;{@link javax.ejb.ActivationConfigProperty} annotation.
 * @author Florent Benoit
 */
public class JActivationConfigProperty implements ActivationConfigProperty {

    /**
     * Name.
     */
    private String name = null;

    /**
     * Value.
     */
    private String value = null;

    /**
     * Constructor.<br>
     * Build an object with a given name and a given value.
     * @param name given name
     * @param value given value
     */
    public JActivationConfigProperty(final String name, final String value) {
        this.name = name;
        this.value = value;
    }


    /**
     * @return property name
     */
    public String propertyName() {
        return name;
    }

    /**
     * @return property value
     */
    public String propertyValue() {
        return value;
    }

    /**
     * @return annotation type
     */
    public Class<? extends Annotation> annotationType() {
        return ActivationConfigProperty.class;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        // property name
        sb.append("[propertyName=");
        sb.append(name);

        // property value
        sb.append(", propertyValue=");
        sb.append(value);

        sb.append("]");
        return sb.toString();
    }
}
