/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JInterceptors.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.impl;

import java.util.ArrayList;
import java.util.List;


/**
 * List of interceptor classes.
 * @author Florent Benoit
 */
public class JInterceptors {

    /**
     * List of classes.
     */
    private List<String> classes = null;

    /**
     * Constructor.
     */
    public JInterceptors() {
        classes = new ArrayList<String>();
    }

    /**
     * Add a class.
     * @param cls name of the class (asm)
     */
    public void addClass(final String cls) {
        classes.add(cls);
    }

    /**
     * @return list of classes.
     */
    public List<String> getClasses() {
        return classes;
    }

    /**
     * @param cls the name of an encoded class.
     * @return true if the class is already in the list.
     */
    public boolean contains(final String cls) {
        return classes.contains(cls);
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // list
        sb.append(classes);
        return sb.toString();
    }

    /**
     * @return the size.
     */
    public int size() {
        return classes.size();
    }

}
