/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxPersistenceContext.java 2067 2007-11-27 10:03:12Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.impl;

import javax.persistence.PersistenceContextType;

import org.ow2.easybeans.deployment.api.IJavaxPersistenceContext;

/**
 * This class allow to set informations on javax.persistence.PersistenceContext
 * annotation.
 * @author Florent Benoit
 */
public class JavaxPersistenceContext implements IJavaxPersistenceContext {

    /**
     * Name of this persistence context.
     */
    private String name = null;

    /**
     * Unit name of this persistence context.
     */
    private String unitName = null;

    /**
     * Type of persistence context.
     */
    private PersistenceContextType type = null;

    /**
     * Build new object with default values.
     */
    public JavaxPersistenceContext() {
        // default values
        this.name = "";
        this.unitName = "";
        this.type = PersistenceContextType.TRANSACTION;
    }

    /**
     * @return the type of persistence context.
     */
    public PersistenceContextType getType() {
        return type;
    }

    /**
     * Sets the persistence context type.
     * @param type given type.
     */
    public void setType(final PersistenceContextType type) {
        this.type = type;
    }

    /**
     * @return the unit name used by this persistence context.
     */
    public String getUnitName() {
        return unitName;
    }

    /**
     * sets the unit name of this persistence context.
     * @param unitName the name of the persistence unit
     */
    public void setUnitName(final String unitName) {
        this.unitName = unitName;
    }

    /**
     * @return the unit name used by this persistence context.
     */
    public String getName() {
        return name;
    }

    /**
     * sets the name of this persistence context.
     * @param name the name of the persistence context
     */
    public void setName(final String name) {
        this.name = name;
    }

}
