/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MessageDriven.java 2059 2007-11-22 17:22:33Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.easybeans.deployment.xml.struct.common.ActivationConfig;


/**
 * Defines a representation for &lt;message-driven&gt; element.
 * @author Florent Benoit
 */
public class MessageDriven extends AbsBean {

    /**
     * Name of this element.
     */
    public static final String NAME = "message-driven";

    /**
     * The messaging-type element specifies the message listener interface of
     * the message-driven bean.
     */
    private String messagingType = null;

    /**
     * The message destination type.
     */
    private String messageDestinationType = null;

    /**
     * The message destination link.
     */
    private String messageDestinationLink = null;

    /**
     * List of activation-config properties.
     */
    private List<ActivationConfig> activationConfigList = null;

    /**
     * Constructor.
     */
    public MessageDriven() {
        super();
        this.activationConfigList = new ArrayList<ActivationConfig>();
    }

    /**
     * Set the messaging-type.
     * @param messagingType the message listener interface of the message-driven
     *        bean.
     */
    public void setMessagingType(final String messagingType) {
        this.messagingType = messagingType;
    }

    /**
     * Gets the messaging-type.
     * @return the messaging-type
     */
    public String getMessagingType() {
        return messagingType;
    }

   /**
     * Set the message destination type.
     * @param messageDestinationType message destination type.
     */
    public void setMessageDestinationType(final String messageDestinationType) {
        this.messageDestinationType = messageDestinationType;
    }

    /**
     * Gets the message destination type.
     * @return the message destination type
     */
    public String getMessageDestinationType() {
        return messageDestinationType;
    }

    /**
     * Set the message destination link.
     * @param messageDestinationLink message destination link.
     */
    public void setMessageDestinationLink(final String messageDestinationLink) {
        this.messageDestinationLink = messageDestinationLink;
    }

    /**
     * Gets the message destination link.
     * @return the message destination link
     */
    public String getMessageDestinationLink() {
        return messageDestinationLink;
    }

    /**
     * Gets the activation-config list.
     * @return activation-config list
     */
    public List<ActivationConfig> getActivationConfigList() {
        return activationConfigList;
    }

    /**
     * Add the activation-config property.
     * @param activationConfig activation-config property
     */
    public void addActivationConfig(final ActivationConfig activationConfig) {
        activationConfigList.add(activationConfig);
    }
}
