/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:WAR.java 2059 2007-11-22 17:22:33Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.xml.struct;

import java.util.LinkedList;
import java.util.List;

/**
 * This class represents a WEB deployment descriptor.
 * @author Florent Benoit
 */
public class WAR {

    /**
     * List of servlet objects.
     */
    private List<Servlet> servlets = null;


    /**
     * List of listener objects.
     */
    private List<Listener> listeners = null;

    /**
     * List of tag objects.
     */
    private List<Tag> tags = null;


    /**
     * Default constructor.
     */
    public WAR() {
        this.servlets = new LinkedList<Servlet>();
        this.listeners = new LinkedList<Listener>();
        this.tags = new LinkedList<Tag>();
    }

    /**
     * Add a given servlet.
     * @param servlet the given servlet object.
     */
    public void addServlet(final Servlet servlet) {
        this.servlets.add(servlet);
    }

    /**
     * @return list of servlets.
     */
    public List<Servlet> getServlets() {
        return this.servlets;
    }

    /**
     * Add a given listener.
     * @param listener the given servlet object.
     */
    public void addListener(final Listener listener) {
        this.listeners.add(listener);
    }

    /**
     * @return list of listeners.
     */
    public List<Listener> getListeners() {
        return this.listeners;
    }

    /**
     * Add a given tag.
     * @param tag the given tag object.
     */
    public void addTag(final Tag tag) {
        this.tags.add(tag);
    }

    /**
     * @return list of tags.
     */
    public List<Tag> getTags() {
        return this.tags;
    }
}
